@@ -93,6 +93,7 @@ type SvcInitRequest struct {
 	Image              string
 	SvcPort            string
 	TopicSubscriptions []string
+	IngressType        string
 }
 
 // SvcShowRequest contains the parameters for calling copilot svc show.
@@ -274,22 +275,26 @@ func NewCLIWithDir(workingDir string) (*CLI, error) {
 	return cli, nil
 }
 
-/*Help runs
+/*
+Help runs
 copilot --help
 */
 func (cli *CLI) Help() (string, error) {
 	return cli.exec(exec.Command(cli.path, "--help"))
 }
 
-/*Version runs:
+/*
+Version runs:
 copilot --version
 */
 func (cli *CLI) Version() (string, error) {
 	return cli.exec(exec.Command(cli.path, "--version"))
 }
 
-/*Init runs:
+/*
+Init runs:
 copilot init
+
 	--app $p
 	--svc $s
 	--svc-type $type
@@ -326,8 +331,10 @@ func (cli *CLI) Init(opts *InitRequest) (string, error) {
 			portOption, opts.SvcPort))
 }
 
-/*SvcInit runs:
+/*
+SvcInit runs:
 copilot svc init
+
 	--name $n
 	--svc-type $t
 	--port $port
@@ -352,12 +359,17 @@ func (cli *CLI) SvcInit(opts *SvcInitRequest) (string, error) {
 	if len(opts.TopicSubscriptions) > 0 {
 		args = append(args, "--subscribe-topics", strings.Join(opts.TopicSubscriptions, ","))
 	}
+	if opts.IngressType != "" {
+		args = append(args, "--ingress-type", opts.IngressType)
+	}
 	return cli.exec(
 		exec.Command(cli.path, args...))
 }
 
-/*SvcShow runs:
+/*
+SvcShow runs:
 copilot svc show
+
 	--app $p
 	--name $n
 	--json
@@ -384,8 +396,10 @@ func (cli *CLI) SvcShow(opts *SvcShowRequest) (*SvcShowOutput, error) {
 	return toSvcShowOutput(svcJSON)
 }
 
-/*SvcStatus runs:
+/*
+SvcStatus runs:
 copilot svc status
+
 	--app $p
 	--env $e
 	--name $n
@@ -406,8 +420,10 @@ func (cli *CLI) SvcStatus(opts *SvcStatusRequest) (*SvcStatusOutput, error) {
 	return toSvcStatusOutput(svcJSON)
 }
 
-/*SvcExec runs:
+/*
+SvcExec runs:
 copilot svc exec
+
 	--app $p
 	--env $e
 	--name $n
@@ -428,8 +444,10 @@ func (cli *CLI) SvcExec(opts *SvcExecRequest) (string, error) {
 			"--yes=false"))
 }
 
-/*SvcDelete runs:
+/*
+SvcDelete runs:
 copilot svc delete
+
 	--name $n
 	--yes
 */
@@ -440,8 +458,10 @@ func (cli *CLI) SvcDelete(serviceName string) (string, error) {
 			"--yes"))
 }
 
-/*SvcDeploy runs:
+/*
+SvcDeploy runs:
 copilot svc deploy
+
 	--name $n
 	--env $e
 	--tag $t
@@ -459,8 +479,10 @@ func (cli *CLI) SvcDeploy(opts *SvcDeployInput) (string, error) {
 		exec.Command(cli.path, arguments...))
 }
 
-/*SvcList runs:
+/*
+SvcList runs:
 copilot svc ls
+
 	--app $p
 	--json
 */
@@ -475,8 +497,10 @@ func (cli *CLI) SvcList(appName string) (*SvcListOutput, error) {
 	return toSvcListOutput(output)
 }
 
-/*SvcLogs runs:
+/*
+SvcLogs runs:
 copilot svc logs
+
 	--app $p
 	--name $n
 	--since $s
@@ -497,8 +521,10 @@ func (cli *CLI) SvcLogs(opts *SvcLogsRequest) ([]SvcLogsOutput, error) {
 	return toSvcLogsOutput(output)
 }
 
-/*SvcPause runs:
+/*
+SvcPause runs:
 copilot svc pause
+
 	--app $p
 	--name $n
 	--env $e
@@ -512,8 +538,10 @@ func (cli *CLI) SvcPause(opts *SvcPauseRequest) (string, error) {
 			"--yes"))
 }
 
-/*SvcResume runs:
+/*
+SvcResume runs:
 copilot svc pause
+
 	--app $p
 	--name $n
 	--env $e
@@ -526,13 +554,15 @@ func (cli *CLI) SvcResume(opts *SvcResumeRequest) (string, error) {
 			"--env", opts.EnvName))
 }
 
-/*StorageInit runs:
+/*
+StorageInit runs:
 copilot storage init
-	--name $n
-	--storage-type $t
-	--workload $w
-	--engine $e
-  --initial-db $d
+
+		--name $n
+		--storage-type $t
+		--workload $w
+		--engine $e
+	  --initial-db $d
 */
 func (cli *CLI) StorageInit(opts *StorageInitRequest) (string, error) {
 	arguments := []string{
@@ -554,8 +584,10 @@ func (cli *CLI) StorageInit(opts *StorageInitRequest) (string, error) {
 		exec.Command(cli.path, arguments...))
 }
 
-/*EnvDelete runs:
+/*
+EnvDelete runs:
 copilot env delete
+
 	--name $n
 	--yes
 */
@@ -566,8 +598,10 @@ func (cli *CLI) EnvDelete(envName string) (string, error) {
 			"--yes"))
 }
 
-/*EnvInit runs:
+/*
+EnvInit runs:
 copilot env init
+
 	--name $n
 	--app $a
 	--profile $pr
@@ -605,8 +639,10 @@ func (cli *CLI) EnvInit(opts *EnvInitRequest) (string, error) {
 	return cli.exec(exec.Command(cli.path, commands...))
 }
 
-/*EnvDeploy runs:
+/*
+EnvDeploy runs:
 copilot env deploy
+
 	--name $n
 	--app $a
 */
@@ -618,8 +654,10 @@ func (cli *CLI) EnvDeploy(opts *EnvDeployRequest) (string, error) {
 	return cli.exec(exec.Command(cli.path, commands...))
 }
 
-/*EnvShow runs:
+/*
+EnvShow runs:
 copilot env show
+
 	--app $a
 	--name $n
 	--json
@@ -637,8 +675,10 @@ func (cli *CLI) EnvShow(opts *EnvShowRequest) (*EnvShowOutput, error) {
 	return toEnvShowOutput(envJSON)
 }
 
-/*EnvList runs:
+/*
+EnvList runs:
 copilot env ls
+
 	--app $a
 	--json
 */
@@ -653,8 +693,10 @@ func (cli *CLI) EnvList(appName string) (*EnvListOutput, error) {
 	return toEnvListOutput(output)
 }
 
-/*AppInit runs:
+/*
+AppInit runs:
 copilot app init $a
+
 	--domain $d (optionally)
 	--resource-tags $k1=$v1,$k2=$k2 (optionally)
 */
@@ -676,8 +718,10 @@ func (cli *CLI) AppInit(opts *AppInitRequest) (string, error) {
 	return cli.exec(exec.Command(cli.path, commands...))
 }
 
-/*AppShow runs:
+/*
+AppShow runs:
 copilot app show
+
 	--name $n
 	--json
 */
@@ -693,6 +737,7 @@ func (cli *CLI) AppShow(appName string) (*AppShowOutput, error) {
 }
 
 // PipelineInit runs:
+//
 //	copilot pipeline init
 //	--name $n
 //	--url $t
@@ -713,6 +758,7 @@ func (cli *CLI) PipelineInit(opts PipelineInitInput) (string, error) {
 }
 
 // PipelineDeploy runs:
+//
 //	copilot pipeline deploy
 //	--name $n
 //	--yes
@@ -728,6 +774,7 @@ func (cli *CLI) PipelineDeploy(opts PipelineDeployInput) (string, error) {
 }
 
 // PipelineShow runs:
+//
 //	copilot pipeline show
 //	--name $n
 //	--json
@@ -752,6 +799,7 @@ func (cli *CLI) PipelineShow(opts PipelineShowInput) (PipelineShowOutput, error)
 }
 
 // PipelineStatus runs:
+//
 //	copilot pipeline show
 //	--name $n
 //	--json
@@ -775,14 +823,16 @@ func (cli *CLI) PipelineStatus(opts PipelineStatusInput) (PipelineStatusOutput,
 	return out, nil
 }
 
-/*AppList runs:
+/*
+AppList runs:
 copilot app ls
 */
 func (cli *CLI) AppList() (string, error) {
 	return cli.exec(exec.Command(cli.path, "app", "ls"))
 }
 
-/*AppDelete runs:
+/*
+AppDelete runs:
 copilot app delete --yes
 */
 func (cli *CLI) AppDelete() (string, error) {
@@ -792,8 +842,10 @@ func (cli *CLI) AppDelete() (string, error) {
 		exec.Command(cli.path, commands...))
 }
 
-/*TaskRun runs:
+/*
+TaskRun runs:
 copilot task run
+
 	-n $t
 	--dockerfile $d
 	--app $a (optionally)
@@ -829,8 +881,10 @@ func (cli *CLI) TaskRun(input *TaskRunInput) (string, error) {
 	return cli.exec(exec.Command(cli.path, commands...))
 }
 
-/*TaskExec runs:
+/*
+TaskExec runs:
 copilot task exec
+
 	--app $p
 	--env $e
 	--name $n
@@ -847,8 +901,10 @@ func (cli *CLI) TaskExec(opts *TaskExecRequest) (string, error) {
 			"--yes=false"))
 }
 
-/*TaskDelete runs:
+/*
+TaskDelete runs:
 copilot task delete
+
 	--name $n
 	--yes
 	--default (optionally)
@@ -876,8 +932,10 @@ func (cli *CLI) TaskDelete(opts *TaskDeleteInput) (string, error) {
 	)
 }
 
-/*JobInit runs:
+/*
+JobInit runs:
 copilot job init
+
 	--name $n
 	--dockerfile $d
 	--schedule $sched
@@ -903,8 +961,10 @@ func (cli *CLI) JobInit(opts *JobInitInput) (string, error) {
 		exec.Command(cli.path, args...))
 }
 
-/*JobDeploy runs:
+/*
+JobDeploy runs:
 copilot job deploy
+
 	--name $n
 	--env $e
 	--tag $t
@@ -917,8 +977,10 @@ func (cli *CLI) JobDeploy(opts *JobDeployInput) (string, error) {
 			"--tag", opts.ImageTag))
 }
 
-/*JobDelete runs:
+/*
+JobDelete runs:
 copilot job delete
+
 	--name $n
 	--yes
 */
@@ -929,8 +991,10 @@ func (cli *CLI) JobDelete(jobName string) (string, error) {
 			"--yes"))
 }
 
-/*JobList runs:
+/*
+JobList runs:
 copilot job ls
+
 	--json?
 	--local?
 */
@@ -945,8 +1009,10 @@ func (cli *CLI) JobList(appName string) (*JobListOutput, error) {
 	return toJobListOutput(output)
 }
 
-/*JobPackage runs:
+/*
+JobPackage runs:
 copilot job package
+
 	--output-dir $dir
 	--name $name
 	--env $env
@@ -975,8 +1041,10 @@ func (cli *CLI) JobPackage(opts *PackageInput) (string, error) {
 	return cli.exec(exec.Command(cli.path, args...))
 }
 
-/*SvcPackage runs:
+/*
+SvcPackage runs:
 copilot svc package
+
 	--output-dir $dir
 	--name $name
 	--env $env
