@@ -10,6 +10,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/ssm"
 	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
+	"github.com/spf13/afero"
 
 	"github.com/aws/copilot-cli/internal/pkg/exec"
 
@@ -53,9 +54,9 @@ func newDeployOpts(vars deployWkldVars) (*deployOpts, error) {
 		return nil, fmt.Errorf("default session: %v", err)
 	}
 	store := config.NewSSMStore(identity.New(defaultSess), ssm.New(defaultSess), aws.StringValue(defaultSess.Config.Region))
-	ws, err := workspace.New()
+	ws, err := workspace.Use(afero.NewOsFs())
 	if err != nil {
-		return nil, fmt.Errorf("new workspace: %w", err)
+		return nil, err
 	}
 	prompter := prompt.New()
 	return &deployOpts{
