@@ -15,6 +15,7 @@ import (
 
 	awscfn "github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
+	awscloudformation "github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 	"github.com/aws/copilot-cli/internal/pkg/aws/elbv2"
 	"github.com/aws/copilot-cli/internal/pkg/aws/partitions"
@@ -164,7 +165,7 @@ func (d *envDeployer) validateCDN(mft *manifest.Environment) error {
 		err := d.validateALBWorkloadsDontRedirect()
 		var redirErr *errEnvHasPublicServicesWithRedirect
 		switch {
-		case errors.As(err, &redirErr) && mft.ALBIngressRestrictedToCDN():
+		case errors.As(err, &redirErr) && mft.IsPublicLBIngressRestrictedToCDN():
 			return err
 		case errors.As(err, &redirErr):
 			log.Warningln(redirErr.warning())
@@ -184,7 +185,9 @@ func (d *envDeployer) validateALBWorkloadsDontRedirect() error {
 	if err != nil {
 		return fmt.Errorf("get env params: %w", err)
 	}
-
+	if params[cfnstack.EnvParamALBWorkloadsKey] == "" {
+		return nil
+	}
 	services := strings.Split(params[cfnstack.EnvParamALBWorkloadsKey], ",")
 	g, ctx := errgroup.WithContext(context.Background())
 
@@ -279,7 +282,7 @@ func (d *envDeployer) cidrPrefixLists(in *DeployEnvironmentInput) ([]string, err
 	var cidrPrefixListIDs []string
 
 	// Check if ingress is allowed from cloudfront
-	if in.Manifest == nil || !in.Manifest.IsIngressRestrictedToCDN() {
+	if in.Manifest == nil || !in.Manifest.IsPublicLBIngressRestrictedToCDN() {
 		return nil, nil
 	}
 	cfManagedPrefixListID, err := d.cfManagedPrefixListID()
@@ -291,6 +294,17 @@ func (d *envDeployer) cidrPrefixLists(in *DeployEnvironmentInput) ([]string, err
 	return cidrPrefixListIDs, nil
 }
 
+func (d *envDeployer) publicALBSourceIPs(in *DeployEnvironmentInput) []string {
+	if in.Manifest == nil || len(in.Manifest.GetPublicALBSourceIPs()) == 0 {
+		return nil
+	}
+	ips := make([]string, len(in.Manifest.GetPublicALBSourceIPs()))
+	for i, sourceIP := range in.Manifest.GetPublicALBSourceIPs() {
+		ips[i] = string(sourceIP)
+	}
+	return ips
+}
+
 func (d *envDeployer) cfManagedPrefixListID() (string, error) {
 	id, err := d.prefixListGetter.CloudFrontManagedPrefixListID()
 	if err != nil {
@@ -308,6 +322,7 @@ type DeployEnvironmentInput struct {
 	ForceNewUpdate      bool
 	RawManifest         []byte
 	PermissionsBoundary string
+	DisableRollback     bool
 }
 
 // GenerateCloudFormationTemplate returns the environment stack's template and parameter configuration.
@@ -353,8 +368,14 @@ func (d *envDeployer) DeployEnvironment(in *DeployEnvironmentInput) error {
 	if err != nil {
 		return fmt.Errorf("retrieve environment stack force update ID: %w", err)
 	}
+	opts := []awscloudformation.StackOption{
+		awscloudformation.WithRoleARN(d.env.ExecutionRoleARN),
+	}
+	if in.DisableRollback {
+		opts = append(opts, awscloudformation.WithDisableRollback())
+	}
 	conf := cfnstack.NewEnvConfigFromExistingStack(stackInput, lastForceUpdateID, oldParams)
-	return d.envDeployer.UpdateAndRenderEnvironment(conf, stackInput.ArtifactBucketARN, cloudformation.WithRoleARN(d.env.ExecutionRoleARN))
+	return d.envDeployer.UpdateAndRenderEnvironment(conf, stackInput.ArtifactBucketARN, opts...)
 }
 
 func (d *envDeployer) getAppRegionalResources() (*cfnstack.AppRegionalResources, error) {
@@ -384,6 +405,7 @@ func (d *envDeployer) buildStackInput(in *DeployEnvironmentInput) (*deploy.Creat
 	if err != nil {
 		return nil, err
 	}
+
 	return &deploy.CreateEnvironmentInput{
 		Name: d.env.Name,
 		App: deploy.AppInformation{
@@ -396,6 +418,7 @@ func (d *envDeployer) buildStackInput(in *DeployEnvironmentInput) (*deploy.Creat
 		ArtifactBucketARN:    s3.FormatARN(partition.ID(), resources.S3Bucket),
 		ArtifactBucketKeyARN: resources.KMSKeyARN,
 		CIDRPrefixListIDs:    cidrPrefixListIDs,
+		PublicALBSourceIPs:   d.publicALBSourceIPs(in),
 		Mft:                  in.Manifest,
 		ForceUpdate:          in.ForceNewUpdate,
 		RawMft:               in.RawManifest,
