@@ -240,7 +240,7 @@ type environmentManifestWriter interface {
 }
 
 type workspacePathGetter interface {
-	Path() (string, error)
+	Path() string
 }
 
 type wsPipelineManifestReader interface {
@@ -295,7 +295,6 @@ type wsWlDirReader interface {
 	workspacePathGetter
 	wlLister
 	wsEnvironmentsLister
-	ListDockerfiles() ([]string, error)
 	Summary() (*workspace.Summary, error)
 }
 
@@ -316,7 +315,6 @@ type wsPipelineGetter interface {
 }
 
 type wsAppManager interface {
-	Create(appName string) error
 	Summary() (*workspace.Summary, error)
 }
 
@@ -508,8 +506,7 @@ type wsSelector interface {
 	Workload(msg, help string) (string, error)
 }
 
-type initJobSelector interface {
-	dockerfileSelector
+type scheduleSelector interface {
 	Schedule(scheduleTypePrompt, scheduleTypeHelp string, scheduleValidator, rateValidator prompt.ValidatorFunc) (string, error)
 }
 
