@@ -45,6 +45,7 @@ func TestSvcInitOpts_Validate(t *testing.T) {
 		inSvcPort        uint16
 		inSubscribeTags  []string
 		inNoSubscribe    bool
+		inIngressType    string
 
 		setupMocks     func(mocks initSvcMocks)
 		mockFileSystem func(mockFS afero.Fs)
@@ -103,6 +104,21 @@ func TestSvcInitOpts_Validate(t *testing.T) {
 			},
 			wantedErr: errors.New("validate subscribe configuration: cannot specify both --no-subscribe and --subscribe-topics"),
 		},
+		"rdws invalid ingress type error": {
+			inSvcName:        "frontend",
+			inSvcType:        "Request-Driven Web Service",
+			inDockerfilePath: "./hello/Dockerfile",
+			inIngressType:    "invalid",
+
+			setupMocks: func(m initSvcMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
+			mockFileSystem: func(mockFS afero.Fs) {
+				mockFS.MkdirAll("hello", 0755)
+				afero.WriteFile(mockFS, "hello/Dockerfile", []byte("FROM nginx"), 0644)
+			},
+			wantedErr: errors.New(`invalid ingress type "invalid": must be one of Environment or Internet.`),
+		},
 		"valid flags": {
 			inSvcName:        "frontend",
 			inSvcType:        "Load Balanced Web Service",
@@ -115,7 +131,20 @@ func TestSvcInitOpts_Validate(t *testing.T) {
 				mockFS.MkdirAll("hello", 0755)
 				afero.WriteFile(mockFS, "hello/Dockerfile", []byte("FROM nginx"), 0644)
 			},
-			wantedErr: nil,
+		},
+		"valid rdws flags": {
+			inSvcName:        "frontend",
+			inSvcType:        "Request-Driven Web Service",
+			inDockerfilePath: "./hello/Dockerfile",
+			inIngressType:    "Internet",
+
+			setupMocks: func(m initSvcMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
+			mockFileSystem: func(mockFS afero.Fs) {
+				mockFS.MkdirAll("hello", 0755)
+				afero.WriteFile(mockFS, "hello/Dockerfile", []byte("FROM nginx"), 0644)
+			},
 		},
 	}
 
@@ -142,7 +171,8 @@ func TestSvcInitOpts_Validate(t *testing.T) {
 						subscriptions:  tc.inSubscribeTags,
 						noSubscribe:    tc.inNoSubscribe,
 					},
-					port: tc.inSvcPort,
+					port:        tc.inSvcPort,
+					ingressType: tc.inIngressType,
 				},
 				store:     mockstore,
 				fs:        &afero.Afero{Fs: afero.NewMemMapFs()},
@@ -186,6 +216,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 		inSvcPort        uint16
 		inSubscribeTags  []string
 		inNoSubscribe    bool
+		inIngressType    string
 
 		setupMocks func(mocks initSvcMocks)
 
@@ -354,6 +385,56 @@ type: Request-Driven Web Service`), nil)
 			},
 			wantedErr: fmt.Errorf("service name iamoverfortycharacterlongandaninvalidrdwsname is invalid: value must not exceed 40 characters"),
 		},
+		"rdws prompt for ingress type": {
+			inSvcType:        appRunnerSvcType,
+			inSvcName:        wantedSvcName,
+			inSvcPort:        wantedSvcPort,
+			inDockerfilePath: wantedDockerfilePath,
+
+			setupMocks: func(m initSvcMocks) {
+				m.mockStore.EXPECT().GetService(mockAppName, wantedSvcName).Return(nil, &config.ErrNoSuchService{})
+				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedSvcName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedSvcName})
+				m.mockPrompt.EXPECT().SelectOption(gomock.Eq(svcInitIngressTypePrompt), gomock.Any(), gomock.Eq([]prompt.Option{
+					{
+						Value: "Environment",
+					},
+					{
+						Value: "Internet",
+					},
+				}), gomock.Any()).Return("Environment", nil)
+			},
+		},
+		"rdws prompt for ingress type error": {
+			inSvcType:        appRunnerSvcType,
+			inSvcName:        wantedSvcName,
+			inSvcPort:        wantedSvcPort,
+			inDockerfilePath: wantedDockerfilePath,
+
+			setupMocks: func(m initSvcMocks) {
+				m.mockStore.EXPECT().GetService(mockAppName, wantedSvcName).Return(nil, &config.ErrNoSuchService{})
+				m.mockPrompt.EXPECT().SelectOption(gomock.Eq(svcInitIngressTypePrompt), gomock.Any(), gomock.Eq([]prompt.Option{
+					{
+						Value: "Environment",
+					},
+					{
+						Value: "Internet",
+					},
+				}), gomock.Any()).Return("", errors.New("some error"))
+			},
+			wantedErr: errors.New("select ingress type: some error"),
+		},
+		"rdws skip ingress type prompt with flag": {
+			inSvcType:        appRunnerSvcType,
+			inSvcName:        wantedSvcName,
+			inSvcPort:        wantedSvcPort,
+			inDockerfilePath: wantedDockerfilePath,
+			inIngressType:    ingressTypeInternet,
+
+			setupMocks: func(m initSvcMocks) {
+				m.mockStore.EXPECT().GetService(mockAppName, wantedSvcName).Return(nil, &config.ErrNoSuchService{})
+				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedSvcName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedSvcName})
+			},
+		},
 		"skip selecting Dockerfile if image flag is set": {
 			inSvcType:        wantedSvcType,
 			inSvcName:        wantedSvcName,
@@ -649,7 +730,8 @@ type: Request-Driven Web Service`), nil)
 						subscriptions:  tc.inSubscribeTags,
 						appName:        mockAppName,
 					},
-					port: tc.inSvcPort,
+					port:        tc.inSvcPort,
+					ingressType: tc.inIngressType,
 				},
 				store: mockStore,
 				fs:    &afero.Afero{Fs: afero.NewMemMapFs()},
