@@ -16,11 +16,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
 )
 
-const (
-	// NoExposedContainerPort indicates no port should be exposed for the service container.
-	NoExposedContainerPort = "-1"
-)
-
 type backendSvcReadParser interface {
 	template.ReadParser
 	ParseBackendService(template.WorkloadOpts) (*template.Content, error)
@@ -141,8 +136,11 @@ func (s *BackendService) Template() (string, error) {
 	for _, ipNet := range s.manifest.RoutingRule.AllowedSourceIps {
 		allowedSourceIPs = append(allowedSourceIPs, string(ipNet))
 	}
-
-	_, targetContainerPort := s.httpLoadBalancerTarget()
+	var scConfig *template.ServiceConnect
+	if s.manifest.Network.Connect.Enabled() {
+		scConfig = convertServiceConnect(s.manifest.Network.Connect)
+	}
+	targetContainer, targetContainerPort := s.httpLoadBalancerTarget()
 	content, err := s.parser.ParseBackendService(template.WorkloadOpts{
 		AppName:            s.app,
 		EnvName:            s.env,
@@ -166,7 +164,9 @@ func (s *BackendService) Template() (string, error) {
 		HealthCheck:        convertContainerHealthCheck(s.manifest.BackendServiceConfig.ImageConfig.HealthCheck),
 		HTTPTargetContainer: template.HTTPTargetContainer{
 			Port: aws.StringValue(targetContainerPort),
+			Name: aws.StringValue(targetContainer),
 		},
+		ServiceConnect:           scConfig,
 		HTTPHealthCheck:          convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
 		DeregistrationDelay:      deregistrationDelay,
 		AllowedSourceIps:         allowedSourceIPs,
@@ -216,7 +216,7 @@ func (s *BackendService) httpLoadBalancerTarget() (targetContainer *string, targ
 }
 
 func (s *BackendService) containerPort() string {
-	port := NoExposedContainerPort
+	port := template.NoExposedContainerPort
 	if s.manifest.BackendServiceConfig.ImageConfig.Port != nil {
 		port = strconv.FormatUint(uint64(aws.Uint16Value(s.manifest.BackendServiceConfig.ImageConfig.Port)), 10)
 	}
