@@ -42,6 +42,7 @@ const (
 	envParamInternalALBWorkloadsKey        = "InternalALBWorkloads"
 	envParamEFSWorkloadsKey                = "EFSWorkloads"
 	envParamNATWorkloadsKey                = "NATWorkloads"
+	envParamAppRunnerPrivateWorkloadsKey   = "AppRunnerPrivateWorkloads"
 	envParamCreateHTTPSListenerKey         = "CreateHTTPSListener"
 	envParamCreateInternalHTTPSListenerKey = "CreateInternalHTTPSListener"
 	EnvParamServiceDiscoveryEndpoint       = "ServiceDiscoveryEndpoint"
@@ -194,6 +195,10 @@ func (e *EnvStackConfig) Parameters() ([]*cloudformation.Parameter, error) {
 			ParameterKey:   aws.String(envParamNATWorkloadsKey),
 			ParameterValue: aws.String(""),
 		},
+		{
+			ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+			ParameterValue: aws.String(""),
+		},
 	}
 	if e.prevParams == nil {
 		return currParams, nil
@@ -396,21 +401,29 @@ func (e *EnvStackConfig) cdnConfig() *template.CDNConfig {
 	}
 }
 
-func (e *EnvStackConfig) publicHTTPConfig() (template.HTTPConfig, error) {
+func (e *EnvStackConfig) publicHTTPConfig() (template.PublicHTTPConfig, error) {
 	elbAccessLogsConfig, err := convertELBAccessLogsConfig(e.in.Mft)
 	if err != nil {
-		return template.HTTPConfig{}, err
+		return template.PublicHTTPConfig{}, err
 	}
-	return template.HTTPConfig{
-		CIDRPrefixListIDs: e.in.CIDRPrefixListIDs,
-		ImportedCertARNs:  e.importPublicCertARNs(),
-		ELBAccessLogs:     elbAccessLogsConfig,
+
+	return template.PublicHTTPConfig{
+		HTTPConfig: template.HTTPConfig{
+			ImportedCertARNs: e.importPublicCertARNs(),
+			SSLPolicy:        e.getPublicSSLPolicy(),
+		},
+		PublicALBSourceIPs: e.in.PublicALBSourceIPs,
+		CIDRPrefixListIDs:  e.in.CIDRPrefixListIDs,
+		ELBAccessLogs:      elbAccessLogsConfig,
 	}, nil
 }
 
-func (e *EnvStackConfig) privateHTTPConfig() template.HTTPConfig {
-	return template.HTTPConfig{
-		ImportedCertARNs: e.importPrivateCertARNs(),
+func (e *EnvStackConfig) privateHTTPConfig() template.PrivateHTTPConfig {
+	return template.PrivateHTTPConfig{
+		HTTPConfig: template.HTTPConfig{
+			ImportedCertARNs: e.importPrivateCertARNs(),
+			SSLPolicy:        e.getPrivateSSLPolicy(),
+		},
 		CustomALBSubnets: e.internalALBSubnets(),
 	}
 }
@@ -420,11 +433,16 @@ func (e *EnvStackConfig) vpcConfig() (template.VPCConfig, error) {
 	if err != nil {
 		return template.VPCConfig{}, err
 	}
+	flowLogs, err := convertFlowLogsConfig(e.in.Mft)
+	if err != nil {
+		return template.VPCConfig{}, err
+	}
 	return template.VPCConfig{
 		Imported:            e.importVPC(),
 		Managed:             e.managedVPC(),
-		AllowVPCIngress:     aws.BoolValue(e.in.Mft.HTTPConfig.Private.SecurityGroupsConfig.Ingress.VPCIngress),
+		AllowVPCIngress:     e.in.Mft.HTTPConfig.Private.HasVPCIngress(),
 		SecurityGroupConfig: securityGroupConfig,
+		FlowLogs:            flowLogs,
 	}, nil
 }
 
@@ -523,3 +541,11 @@ func (e *EnvStackConfig) internalALBSubnets() []string {
 	// Fallthrough to SSM config.
 	return e.in.InternalALBSubnets
 }
+
+func (e *EnvStackConfig) getPublicSSLPolicy() *string {
+	return e.in.Mft.EnvironmentConfig.HTTPConfig.Public.SSLPolicy
+}
+
+func (e *EnvStackConfig) getPrivateSSLPolicy() *string {
+	return e.in.Mft.EnvironmentConfig.HTTPConfig.Private.SSLPolicy
+}
