@@ -41,6 +41,7 @@ func TestEnv_Template(t *testing.T) {
 								PublicSubnetCIDRs:  DefaultPublicSubnetCIDRs,
 							},
 							SecurityGroupConfig: nil,
+							FlowLogs:            nil,
 						},
 						LatestVersion: deploy.LatestEnvTemplateVersion,
 						CustomResources: map[string]template.S3ObjectLocation{
@@ -163,6 +164,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 		"with DNS": {
@@ -220,6 +225,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 		"with private DNS only": {
@@ -277,6 +286,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("true"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 		"should use default value for new EnvControllerParameters": {
@@ -330,6 +343,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String("rdws-backend"),
+				},
 			},
 
 			want: []*cloudformation.Parameter{
@@ -385,6 +402,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String("rdws-backend"),
+				},
 			},
 		},
 		"should retain the values from EnvControllerParameters": {
@@ -398,6 +419,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamNATWorkloadsKey),
 					ParameterValue: aws.String("backend"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String("rdws-backend"),
+				},
 				{
 					ParameterKey:   aws.String(EnvParamAliasesKey),
 					ParameterValue: aws.String(""),
@@ -497,6 +522,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String("rdws-backend"),
+				},
 			},
 		},
 		"should not include old parameters that are deleted": {
@@ -557,6 +586,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 
 			want: []*cloudformation.Parameter{
@@ -612,6 +645,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 		"should reuse old service discovery endpoint value": {
@@ -669,6 +706,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 
 			want: []*cloudformation.Parameter{
@@ -724,6 +765,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 		"should use app.local endpoint service discovery endpoint if it is a new parameter": {
@@ -753,6 +798,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamAppDNSDelegationRoleKey),
 					ParameterValue: aws.String(""),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 
 			want: []*cloudformation.Parameter{
@@ -808,6 +857,10 @@ func TestEnv_Parameters(t *testing.T) {
 					ParameterKey:   aws.String(envParamCreateInternalHTTPSListenerKey),
 					ParameterValue: aws.String("false"),
 				},
+				{
+					ParameterKey:   aws.String(envParamAppRunnerPrivateWorkloadsKey),
+					ParameterValue: aws.String(""),
+				},
 			},
 		},
 	}
