@@ -7,7 +7,6 @@ package stack_test
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -19,6 +18,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
+	"github.com/spf13/afero"
 	"gopkg.in/yaml.v3"
 
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
@@ -30,7 +30,7 @@ const (
 	svcManifestPath = "svc-manifest.yml"
 )
 
-func TestLoadBalancedWebService_Template(t *testing.T) {
+func TestLoadBalancedWebService_TemplateInteg(t *testing.T) {
 	testCases := map[string]struct {
 		envName       string
 		svcStackPath  string
@@ -62,7 +62,7 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 		require.NoError(t, os.Setenv("TAG", val))
 	}()
 	path := filepath.Join("testdata", "workloads", svcManifestPath)
-	manifestBytes, err := ioutil.ReadFile(path)
+	manifestBytes, err := os.ReadFile(path)
 	require.NoError(t, err)
 	for name, tc := range testCases {
 		interpolated, err := manifest.NewInterpolator(appName, tc.envName).Interpolate(string(manifestBytes))
@@ -80,7 +80,15 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 		v, ok := content.(*manifest.LoadBalancedWebService)
 		require.True(t, ok)
 
-		ws, err := workspace.New()
+		// Create in-memory mock file system.
+		wd, err := os.Getwd()
+		require.NoError(t, err)
+		fs := afero.NewMemMapFs()
+		_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+		_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", wd), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+		require.NoError(t, err)
+
+		ws, err := workspace.Use(fs)
 		require.NoError(t, err)
 
 		_, err = addon.Parse(aws.StringValue(v.Name), ws)
@@ -117,12 +125,12 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 			mActual := make(map[interface{}]interface{})
 			require.NoError(t, yaml.Unmarshal(actualBytes, mActual))
 
-			expected, err := ioutil.ReadFile(filepath.Join("testdata", "workloads", tc.svcStackPath))
+			expected, err := os.ReadFile(filepath.Join("testdata", "workloads", tc.svcStackPath))
 			require.NoError(t, err, "should be able to read expected bytes")
 			expectedBytes := []byte(expected)
 			mExpected := make(map[interface{}]interface{})
 			require.NoError(t, yaml.Unmarshal(expectedBytes, mExpected))
-			require.Equal(t, mExpected, mActual)
+			compareStackTemplate(t, mExpected, mActual)
 		})
 
 		testName = fmt.Sprintf("Parameter values should render properly/%s", name)
@@ -131,7 +139,7 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 			require.NoError(t, err)
 
 			path := filepath.Join("testdata", "workloads", tc.svcParamsPath)
-			wantedCFNParamsBytes, err := ioutil.ReadFile(path)
+			wantedCFNParamsBytes, err := os.ReadFile(path)
 			require.NoError(t, err)
 
 			require.Equal(t, string(wantedCFNParamsBytes), actualParams)
