@@ -125,7 +125,7 @@ func (s *RequestDrivenWebService) Template() (string, error) {
 		Tags:                 s.manifest.Tags,
 		NestedStack:          addonsOutputs,
 		AddonsExtraParams:    addonsParams,
-		EnableHealthCheck:    !s.healthCheckConfig.IsEmpty(),
+		EnableHealthCheck:    !s.healthCheckConfig.IsZero(),
 		WorkloadType:         manifest.RequestDrivenWebServiceType,
 		Alias:                s.manifest.Alias,
 		CustomResources:      crs,
@@ -140,7 +140,10 @@ func (s *RequestDrivenWebService) Template() (string, error) {
 		Observability: template.ObservabilityOpts{
 			Tracing: strings.ToUpper(aws.StringValue(s.manifest.Observability.Tracing)),
 		},
-		PermissionsBoundary: s.permBound,
+		PermissionsBoundary:  s.permBound,
+		Private:              aws.BoolValue(s.manifest.Private.Basic) || s.manifest.Private.Advanced.Endpoint != nil,
+		AppRunnerVPCEndpoint: s.manifest.Private.Advanced.Endpoint,
+		Count:                s.manifest.Count,
 	})
 	if err != nil {
 		return "", err
