@@ -6,7 +6,8 @@
 package stack_test
 
 import (
-	"io/ioutil"
+	"fmt"
+	"os"
 	"path/filepath"
 	"testing"
 
@@ -16,6 +17,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
+	"github.com/spf13/afero"
 	"github.com/stretchr/testify/require"
 )
 
@@ -37,7 +39,7 @@ func Test_Stack_Local_Integration(t *testing.T) {
 	)
 
 	path := filepath.Join("testdata", "stacklocal", autoScalingManifestPath)
-	wantedManifestBytes, err := ioutil.ReadFile(path)
+	wantedManifestBytes, err := os.ReadFile(path)
 	require.NoError(t, err)
 	mft, err := manifest.UnmarshalWorkload(wantedManifestBytes)
 	require.NoError(t, err)
@@ -46,7 +48,15 @@ func Test_Stack_Local_Integration(t *testing.T) {
 	v, ok := content.(*manifest.LoadBalancedWebService)
 	require.Equal(t, ok, true)
 
-	ws, err := workspace.New()
+	// Create in-memory mock file system.
+	wd, err := os.Getwd()
+	require.NoError(t, err)
+	fs := afero.NewMemMapFs()
+	_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+	_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", wd), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+	require.NoError(t, err)
+
+	ws, err := workspace.Use(fs)
 	require.NoError(t, err)
 
 	_, err = addon.Parse(aws.StringValue(v.Name), ws)
@@ -77,7 +87,7 @@ func Test_Stack_Local_Integration(t *testing.T) {
 
 	t.Run("CloudFormation template must contain autoscaling resources", func(t *testing.T) {
 		path := filepath.Join("testdata", "stacklocal", wantedAutoScalingCFNTemplatePath)
-		wantedCFNBytes, err := ioutil.ReadFile(path)
+		wantedCFNBytes, err := os.ReadFile(path)
 		require.NoError(t, err)
 
 		require.Contains(t, tpl, string(wantedCFNBytes))
@@ -85,7 +95,7 @@ func Test_Stack_Local_Integration(t *testing.T) {
 
 	t.Run("CloudFormation template must be overridden correctly", func(t *testing.T) {
 		path := filepath.Join("testdata", "stacklocal", wantedOverrideCFNTemplatePath)
-		wantedCFNBytes, err := ioutil.ReadFile(path)
+		wantedCFNBytes, err := os.ReadFile(path)
 		require.NoError(t, err)
 
 		require.Contains(t, tpl, string(wantedCFNBytes))
@@ -96,7 +106,7 @@ func Test_Stack_Local_Integration(t *testing.T) {
 		require.NoError(t, err)
 
 		path := filepath.Join("testdata", "stacklocal", wantedAutoScalingCFNParameterPath)
-		wantedCFNParamsBytes, err := ioutil.ReadFile(path)
+		wantedCFNParamsBytes, err := os.ReadFile(path)
 		require.NoError(t, err)
 
 		require.Equal(t, params, string(wantedCFNParamsBytes))
