@@ -8,15 +8,12 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"io"
-	"sort"
 	"strconv"
 	"strings"
 	"text/tabwriter"
 
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 
-	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/copilot-cli/internal/pkg/aws/elbv2"
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 
@@ -129,7 +126,8 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 
 	var routes []*WebServiceRoute
 	var configs []*ECSServiceConfig
-	var serviceDiscoveries []*ServiceDiscovery
+	svcDiscoveries := make(serviceDiscoveries)
+	svcConnects := make(serviceConnects)
 	var envVars []*containerEnvVar
 	var secrets []*secret
 	for _, env := range environments {
@@ -160,7 +158,7 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 		configs = append(configs, &ECSServiceConfig{
 			ServiceConfig: &ServiceConfig{
 				Environment: env,
-				Port:        svcParams[cfnstack.WorkloadContainerPortParamKey],
+				Port:        svcParams[cfnstack.WorkloadTargetPortParamKey],
 				CPU:         svcParams[cfnstack.WorkloadTaskCPUParamKey],
 				Memory:      svcParams[cfnstack.WorkloadTaskMemoryParamKey],
 				Platform:    dockerengine.PlatformString(containerPlatform.OperatingSystem, containerPlatform.Architecture),
@@ -171,15 +169,13 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 		if err != nil {
 			return nil, err
 		}
-		endpoint, err := envDescr.ServiceDiscoveryEndpoint()
-		if err != nil {
+		if err := svcDiscoveries.collectEndpoints(
+			envDescr, d.svc, env, svcParams[cfnstack.WorkloadTargetPortParamKey]); err != nil {
+			return nil, err
+		}
+		if err := svcConnects.collectEndpoints(svcDescr, env); err != nil {
 			return nil, err
 		}
-		serviceDiscoveries = appendServiceDiscovery(serviceDiscoveries, serviceDiscovery{
-			Service:  d.svc,
-			Port:     svcParams[cfnstack.WorkloadContainerPortParamKey],
-			Endpoint: endpoint,
-		}, env)
 		envVars = append(envVars, flattenContainerEnvVars(env, webSvcEnvVars)...)
 		webSvcSecrets, err := svcDescr.Secrets()
 		if err != nil {
@@ -203,17 +199,20 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	}
 
 	return &webSvcDesc{
-		Service:          d.svc,
-		Type:             manifest.LoadBalancedWebServiceType,
-		App:              d.app,
-		Configurations:   configs,
-		Routes:           routes,
-		ServiceDiscovery: serviceDiscoveries,
-		Variables:        envVars,
-		Secrets:          secrets,
-		Resources:        resources,
+		ecsSvcDesc: ecsSvcDesc{
+			Service:          d.svc,
+			Type:             manifest.LoadBalancedWebServiceType,
+			App:              d.app,
+			Configurations:   configs,
+			Routes:           routes,
+			ServiceDiscovery: svcDiscoveries,
+			ServiceConnect:   svcConnects,
+			Variables:        envVars,
+			Secrets:          secrets,
+			Resources:        resources,
 
-		environments: environments,
+			environments: environments,
+		},
 	}, nil
 }
 
@@ -227,98 +226,15 @@ func (d *LBWebServiceDescriber) Manifest(env string) ([]byte, error) {
 	return cfn.Manifest()
 }
 
-type secret struct {
-	Name        string `json:"name"`
-	Container   string `json:"container"`
-	Environment string `json:"environment"`
-	ValueFrom   string `json:"valueFrom"`
-}
-
-type secrets []*secret
-
-func (s secrets) humanString(w io.Writer) {
-	headers := []string{"Name", "Container", "Environment", "Value From"}
-	fmt.Fprintf(w, "  %s\n", strings.Join(headers, "\t"))
-	fmt.Fprintf(w, "  %s\n", strings.Join(underline(headers), "\t"))
-	sort.SliceStable(s, func(i, j int) bool { return s[i].Environment < s[j].Environment })
-	sort.SliceStable(s, func(i, j int) bool { return s[i].Container < s[j].Container })
-	sort.SliceStable(s, func(i, j int) bool { return s[i].Name < s[j].Name })
-	if len(s) > 0 {
-		valueFrom := s[0].ValueFrom
-		if _, err := arn.Parse(s[0].ValueFrom); err != nil {
-			// If the valueFrom is not an ARN, preface it with "parameter/"
-			valueFrom = fmt.Sprintf("parameter/%s", s[0].ValueFrom)
-		}
-		fmt.Fprintf(w, "  %s\n", strings.Join([]string{s[0].Name, s[0].Container, s[0].Environment, valueFrom}, "\t"))
-	}
-	for prev, cur := 0, 1; cur < len(s); prev, cur = prev+1, cur+1 {
-		valueFrom := s[cur].ValueFrom
-		if _, err := arn.Parse(s[cur].ValueFrom); err != nil {
-			// If the valueFrom is not an ARN, preface it with "parameter/"
-			valueFrom = fmt.Sprintf("parameter/%s", s[cur].ValueFrom)
-		}
-		cols := []string{s[cur].Name, s[cur].Container, s[cur].Environment, valueFrom}
-		if s[prev].Name == s[cur].Name {
-			cols[0] = dittoSymbol
-		}
-		if s[prev].Container == s[cur].Container {
-			cols[1] = dittoSymbol
-		}
-		if s[prev].Environment == s[cur].Environment {
-			cols[2] = dittoSymbol
-		}
-		if s[prev].ValueFrom == s[cur].ValueFrom {
-			cols[3] = dittoSymbol
-		}
-		fmt.Fprintf(w, "  %s\n", strings.Join(cols, "\t"))
-	}
-}
-
-func underline(headings []string) []string {
-	var lines []string
-	for _, heading := range headings {
-		line := strings.Repeat("-", len(heading))
-		lines = append(lines, line)
-	}
-	return lines
-}
-
 // WebServiceRoute contains serialized route parameters for a web service.
 type WebServiceRoute struct {
 	Environment string `json:"environment"`
 	URL         string `json:"url"`
 }
 
-// ServiceDiscovery contains serialized service discovery info for an service.
-type ServiceDiscovery struct {
-	Environment []string `json:"environment"`
-	Namespace   string   `json:"namespace"`
-}
-
-type serviceDiscoveries []*ServiceDiscovery
-
-func (s serviceDiscoveries) humanString(w io.Writer) {
-	headers := []string{"Environment", "Namespace"}
-	fmt.Fprintf(w, "  %s\n", strings.Join(headers, "\t"))
-	fmt.Fprintf(w, "  %s\n", strings.Join(underline(headers), "\t"))
-	for _, sd := range s {
-		fmt.Fprintf(w, "  %s\t%s\n", strings.Join(sd.Environment, ", "), sd.Namespace)
-	}
-}
-
 // webSvcDesc contains serialized parameters for a web service.
 type webSvcDesc struct {
-	Service          string               `json:"service"`
-	Type             string               `json:"type"`
-	App              string               `json:"application"`
-	Configurations   ecsConfigurations    `json:"configurations"`
-	Routes           []*WebServiceRoute   `json:"routes"`
-	ServiceDiscovery serviceDiscoveries   `json:"serviceDiscovery"`
-	Variables        containerEnvVars     `json:"variables"`
-	Secrets          secrets              `json:"secrets,omitempty"`
-	Resources        deployedSvcResources `json:"resources,omitempty"`
-
-	environments []string
+	ecsSvcDesc
 }
 
 // JSONString returns the stringified webSvcDesc struct in json format.
@@ -350,9 +266,15 @@ func (w *webSvcDesc) HumanString() string {
 	for _, route := range w.Routes {
 		fmt.Fprintf(writer, "  %s\t%s\n", route.Environment, route.URL)
 	}
-	fmt.Fprint(writer, color.Bold.Sprint("\nService Discovery\n\n"))
-	writer.Flush()
-	w.ServiceDiscovery.humanString(writer)
+	if len(w.ServiceConnect) > 0 || len(w.ServiceDiscovery) > 0 {
+		fmt.Fprint(writer, color.Bold.Sprint("\nInternal Service Endpoint\n\n"))
+		writer.Flush()
+		endpoints := serviceEndpoints{
+			discoveries: w.ServiceDiscovery,
+			connects:    w.ServiceConnect,
+		}
+		endpoints.humanString(writer)
+	}
 	fmt.Fprint(writer, color.Bold.Sprint("\nVariables\n\n"))
 	writer.Flush()
 	w.Variables.humanString(writer)
@@ -394,20 +316,3 @@ func IsStackNotExistsErr(err error) bool {
 	}
 	return true
 }
-
-func appendServiceDiscovery(sds []*ServiceDiscovery, sd serviceDiscovery, env string) []*ServiceDiscovery {
-	exist := false
-	for _, s := range sds {
-		if s.Namespace == sd.String() {
-			s.Environment = append(s.Environment, env)
-			exist = true
-		}
-	}
-	if !exist {
-		sds = append(sds, &ServiceDiscovery{
-			Environment: []string{env},
-			Namespace:   sd.String(),
-		})
-	}
-	return sds
-}
