@@ -11,6 +11,7 @@ import (
 	ecsapi "github.com/aws/aws-sdk-go/service/ecs"
 
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/aws/apprunner"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	awsecs "github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/describe/mocks"
@@ -288,6 +289,84 @@ func TestServiceDescriber_EnvVars(t *testing.T) {
 	}
 }
 
+func TestServiceDescriber_ServiceConnectDNSNames(t *testing.T) {
+	const (
+		testApp = "phonetool"
+		testSvc = "svc"
+		testEnv = "test"
+	)
+	testCases := map[string]struct {
+		setupMocks func(mocks ecsSvcDescriberMocks)
+
+		wantedDNSNames []string
+		wantedError    error
+	}{
+		"returns error if fails to get ECS service": {
+			setupMocks: func(m ecsSvcDescriberMocks) {
+				m.mockECSClient.EXPECT().Service(testApp, testEnv, testSvc).Return(nil, errors.New("some error"))
+			},
+
+			wantedError: errors.New("get service svc: some error"),
+		},
+		"success": {
+			setupMocks: func(m ecsSvcDescriberMocks) {
+				m.mockECSClient.EXPECT().Service(testApp, testEnv, testSvc).Return(&awsecs.Service{
+					Deployments: []*ecsapi.Deployment{
+						{
+							ServiceConnectConfiguration: &ecsapi.ServiceConnectConfiguration{
+								Enabled:   aws.Bool(true),
+								Namespace: aws.String("foobar.com"),
+								Services: []*ecsapi.ServiceConnectService{
+									{
+										PortName: aws.String("frontend"),
+									},
+								},
+							},
+						},
+					},
+				}, nil)
+			},
+
+			wantedDNSNames: []string{"frontend.foobar.com"},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// GIVEN
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			mockecsClient := mocks.NewMockecsClient(ctrl)
+			mocks := ecsSvcDescriberMocks{
+				mockECSClient: mockecsClient,
+			}
+
+			tc.setupMocks(mocks)
+
+			d := &ecsServiceDescriber{
+				serviceStackDescriber: &serviceStackDescriber{
+					app:     testApp,
+					service: testSvc,
+					env:     testEnv,
+				},
+				ecsClient: mockecsClient,
+			}
+
+			// WHEN
+			actual, err := d.ServiceConnectDNSNames()
+
+			// THEN
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				require.ElementsMatch(t, tc.wantedDNSNames, actual)
+			}
+		})
+	}
+}
+
 func TestServiceDescriber_Secrets(t *testing.T) {
 	const (
 		testApp = "phonetool"
@@ -553,3 +632,183 @@ func TestServiceDescriber_Platform(t *testing.T) {
 		})
 	}
 }
+
+type apprunnerMocks struct {
+	apprunnerClient *mocks.MockapprunnerClient
+	stackDescriber  *mocks.MockstackDescriber
+}
+
+func TestAppRunnerServiceDescriber_ServiceURL(t *testing.T) {
+	mockErr := errors.New("some error")
+	mockVICARN := "mockVICARN"
+	mockServiceARN := "mockServiceARN"
+	tests := map[string]struct {
+		setupMocks func(m apprunnerMocks)
+
+		expected    string
+		expectedErr string
+	}{
+		"get ingress connection error": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return(nil, mockErr)
+			},
+			expectedErr: "some error",
+		},
+		"get private url error": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       apprunnerVPCIngressConnectionType,
+						PhysicalID: mockVICARN,
+					},
+				}, nil)
+				m.apprunnerClient.EXPECT().PrivateURL(mockVICARN).Return("", mockErr)
+			},
+			expectedErr: "some error",
+		},
+		"private service, success": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       apprunnerVPCIngressConnectionType,
+						PhysicalID: mockVICARN,
+					},
+				}, nil)
+				m.apprunnerClient.EXPECT().PrivateURL(mockVICARN).Return("example.com", nil)
+			},
+			expected: "https://example.com",
+		},
+		"public service, resources fails": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return(nil, nil)
+				m.stackDescriber.EXPECT().Resources().Return(nil, mockErr)
+			},
+			expectedErr: "some error",
+		},
+		"public service, no app runner resource": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       "random",
+						PhysicalID: "random",
+					},
+				}, nil)
+			},
+			expectedErr: "no App Runner Service in service stack",
+		},
+		"public service, describe service fails": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       apprunnerServiceType,
+						PhysicalID: mockServiceARN,
+					},
+				}, nil)
+				m.apprunnerClient.EXPECT().DescribeService(mockServiceARN).Return(nil, mockErr)
+			},
+			expectedErr: "describe service: some error",
+		},
+		"public service, success": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       apprunnerServiceType,
+						PhysicalID: mockServiceARN,
+					},
+				}, nil)
+				m.apprunnerClient.EXPECT().DescribeService(mockServiceARN).Return(&apprunner.Service{
+					ServiceURL: "example.com",
+				}, nil)
+			},
+			expected: "https://example.com",
+		},
+	}
+
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := apprunnerMocks{
+				apprunnerClient: mocks.NewMockapprunnerClient(ctrl),
+				stackDescriber:  mocks.NewMockstackDescriber(ctrl),
+			}
+			tc.setupMocks(m)
+
+			d := &appRunnerServiceDescriber{
+				serviceStackDescriber: &serviceStackDescriber{
+					cfn: m.stackDescriber,
+				},
+				apprunnerClient: m.apprunnerClient,
+			}
+
+			url, err := d.ServiceURL()
+			if tc.expectedErr != "" {
+				require.EqualError(t, err, tc.expectedErr)
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.expected, url)
+			}
+		})
+	}
+}
+
+func TestAppRunnerServiceDescriber_IsPrivate(t *testing.T) {
+	mockErr := errors.New("some error")
+	tests := map[string]struct {
+		setupMocks func(m apprunnerMocks)
+
+		expected    bool
+		expectedErr string
+	}{
+		"get resources error": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return(nil, mockErr)
+			},
+			expectedErr: "some error",
+		},
+		"is not private": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return(nil, nil)
+			},
+			expected: false,
+		},
+		"is private": {
+			setupMocks: func(m apprunnerMocks) {
+				m.stackDescriber.EXPECT().Resources().Return([]*stack.Resource{
+					{
+						Type:       apprunnerVPCIngressConnectionType,
+						PhysicalID: "arn",
+					},
+				}, nil)
+			},
+			expected: true,
+		},
+	}
+
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := apprunnerMocks{
+				stackDescriber: mocks.NewMockstackDescriber(ctrl),
+			}
+			tc.setupMocks(m)
+
+			d := &appRunnerServiceDescriber{
+				serviceStackDescriber: &serviceStackDescriber{
+					cfn: m.stackDescriber,
+				},
+			}
+
+			isPrivate, err := d.IsPrivate()
+			if tc.expectedErr != "" {
+				require.EqualError(t, err, tc.expectedErr)
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.expected, isPrivate)
+			}
+		})
+	}
+}
