@@ -4,7 +4,6 @@
 package manifest
 
 import (
-	"errors"
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -27,10 +26,6 @@ const (
 	GRPCProtocol = "gRPC" // GRPCProtocol is the HTTP protocol version for gRPC.
 )
 
-var (
-	errUnmarshalHealthCheckArgs = errors.New("can't unmarshal healthcheck field into string or compose-style map")
-)
-
 // durationp is a utility function used to convert a time.Duration to a pointer. Useful for YAML unmarshaling
 // and template execution.
 func durationp(v time.Duration) *time.Duration {
@@ -104,7 +99,7 @@ func newDefaultHTTPLoadBalancedWebService() *LoadBalancedWebService {
 	lbws.RoutingRule = RoutingRuleConfigOrBool{
 		RoutingRuleConfiguration: RoutingRuleConfiguration{
 			HealthCheck: HealthCheckArgsOrString{
-				HealthCheckPath: aws.String(DefaultHealthCheckPath),
+				Union: BasicToUnion[string, HTTPHealthCheckArgs](DefaultHealthCheckPath),
 			},
 		},
 	}
