@@ -41,6 +41,8 @@ cpu: 512
 memory: 1024
 count: 1
 exec: true
+network:
+  connect: true
 http:
   path: "svc"
   target_container: "frontend"
@@ -109,11 +111,9 @@ environments:
 										},
 									},
 								},
-								Path:            aws.String("svc"),
-								TargetContainer: aws.String("frontend"),
-								HealthCheck: HealthCheckArgsOrString{
-									HealthCheckPath: nil,
-								},
+								Path:             aws.String("svc"),
+								TargetContainer:  aws.String("frontend"),
+								HealthCheck:      HealthCheckArgsOrString{},
 								AllowedSourceIps: []IPNet{IPNet("10.1.0.0/24"), IPNet("10.1.1.0/24")},
 							},
 						},
@@ -161,6 +161,9 @@ environments:
 									PlacementString: placementStringP(PublicSubnetPlacement),
 								},
 							},
+							Connect: ServiceConnectBoolOrArgs{
+								EnableServiceConnect: aws.Bool(true),
+							},
 						},
 						TaskDefOverrides: []OverrideRule{
 							{
@@ -765,15 +768,13 @@ func TestHealthCheckArgsOrString_IsEmpty(t *testing.T) {
 		},
 		"should return false if a path is set via the basic configuration": {
 			hc: HealthCheckArgsOrString{
-				HealthCheckPath: aws.String("/"),
+				Union: BasicToUnion[string, HTTPHealthCheckArgs]("/"),
 			},
 			wanted: false,
 		},
 		"should return false if a value is set via the advanced configuration": {
 			hc: HealthCheckArgsOrString{
-				HealthCheckArgs: HTTPHealthCheckArgs{
-					Path: aws.String("/"),
-				},
+				Union: BasicToUnion[string, HTTPHealthCheckArgs]("/"),
 			},
 			wanted: false,
 		},
@@ -781,7 +782,7 @@ func TestHealthCheckArgsOrString_IsEmpty(t *testing.T) {
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			require.Equal(t, tc.wanted, tc.hc.IsEmpty())
+			require.Equal(t, tc.wanted, tc.hc.IsZero())
 		})
 	}
 }
