@@ -175,8 +175,8 @@ func TestEnvironmentConfig_validate(t *testing.T) {
 				},
 				HTTPConfig: EnvironmentHTTPConfig{
 					Public: PublicHTTPConfig{
-						SecurityGroupConfig: ALBSecurityGroupsConfig{
-							Ingress: Ingress{
+						DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+							DeprecatedIngress: DeprecatedIngress{
 								RestrictiveIngress: RestrictiveIngress{
 									CDNIngress: aws.Bool(true),
 								},
@@ -187,6 +187,30 @@ func TestEnvironmentConfig_validate(t *testing.T) {
 			},
 			wantedError: "CDN must be enabled to limit security group ingress to CloudFront",
 		},
+		"valid vpc flowlogs with default retention": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						FlowLogs: Union[*bool, VPCFlowLogsArgs]{
+							Basic: aws.Bool(true),
+						},
+					},
+				},
+			},
+		},
+		"valid vpc flowlogs with a specified retention": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						FlowLogs: Union[*bool, VPCFlowLogsArgs]{
+							Advanced: VPCFlowLogsArgs{
+								Retention: aws.Int(30),
+							},
+						},
+					},
+				},
+			},
+		},
 		"valid elb access logs config with bucket_prefix": {
 			in: EnvironmentConfig{
 				HTTPConfig: EnvironmentHTTPConfig{
@@ -292,6 +316,67 @@ func TestEnvironmentConfig_validate(t *testing.T) {
 				},
 			},
 		},
+		"returns error when http private config with deprecated and a new ingress field": {
+			in: EnvironmentConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
+					Private: privateHTTPConfig{
+						Ingress: RelaxedIngress{
+							VPCIngress: aws.Bool(true),
+						},
+						DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+							DeprecatedIngress: DeprecatedIngress{
+								VPCIngress: aws.Bool(true),
+							},
+						},
+					},
+				},
+			},
+			wantedError: "validate \"http config\": validate \"private\": must specify one, not both, of \"private.http.security_groups.ingress\" and \"private.http.ingress\"",
+		},
+		"no error when http private config with a new ingress field": {
+			in: EnvironmentConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
+					Private: privateHTTPConfig{
+						Ingress: RelaxedIngress{
+							VPCIngress: aws.Bool(true),
+						},
+					},
+				},
+			},
+		},
+		"returns error when http public config with deprecated and a new ingress field": {
+			in: EnvironmentConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						Ingress: RestrictiveIngress{
+							CDNIngress: aws.Bool(true),
+						},
+						DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+							DeprecatedIngress: DeprecatedIngress{
+								RestrictiveIngress: RestrictiveIngress{
+									CDNIngress: aws.Bool(true),
+								},
+							},
+						},
+					},
+				},
+			},
+			wantedError: "validate \"http config\": validate \"public\": must specify one, not both, of \"public.http.security_groups.ingress\" and \"public.http.ingress\"",
+		},
+		"no error when http public config with a new ingress field": {
+			in: EnvironmentConfig{
+				CDNConfig: EnvironmentCDNConfig{
+					Enabled: aws.Bool(true),
+				},
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						Ingress: RestrictiveIngress{
+							CDNIngress: aws.Bool(true),
+						},
+					},
+				},
+			},
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -777,14 +862,6 @@ func TestCDNConfiguration_validate(t *testing.T) {
 			},
 			wantedError: errors.New("cdn certificate must be in region us-east-1"),
 		},
-		"error if terminate tls set without cert": {
-			in: EnvironmentCDNConfig{
-				Config: AdvancedCDNConfig{
-					TerminateTLS: aws.Bool(true),
-				},
-			},
-			wantedError: errors.New(`"certificate" must be specified if "terminate_tls" is specified`),
-		},
 		"success with cert and terminate tls": {
 			in: EnvironmentCDNConfig{
 				Config: AdvancedCDNConfig{
@@ -912,8 +989,8 @@ func TestEnvironmentHTTPConfig_validate(t *testing.T) {
 		"public http config with invalid security group ingress": {
 			in: EnvironmentHTTPConfig{
 				Public: PublicHTTPConfig{
-					SecurityGroupConfig: ALBSecurityGroupsConfig{
-						Ingress: Ingress{
+					DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+						DeprecatedIngress: DeprecatedIngress{
 							VPCIngress: aws.Bool(true),
 						},
 					},
@@ -924,8 +1001,8 @@ func TestEnvironmentHTTPConfig_validate(t *testing.T) {
 		"private http config with invalid security group ingress": {
 			in: EnvironmentHTTPConfig{
 				Private: privateHTTPConfig{
-					SecurityGroupsConfig: securityGroupsConfig{
-						Ingress: Ingress{
+					DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+						DeprecatedIngress: DeprecatedIngress{
 							RestrictiveIngress: RestrictiveIngress{
 								CDNIngress: aws.Bool(true),
 							},
@@ -935,6 +1012,18 @@ func TestEnvironmentHTTPConfig_validate(t *testing.T) {
 			},
 			wantedError: fmt.Errorf(`validate "private": an internal load balancer cannot have restrictive ingress fields`),
 		},
+		"public http config with invalid source ips": {
+			in: EnvironmentHTTPConfig{
+				Public: PublicHTTPConfig{
+					DeprecatedSG: DeprecatedALBSecurityGroupsConfig{
+						DeprecatedIngress: DeprecatedIngress{
+							RestrictiveIngress: RestrictiveIngress{SourceIPs: []IPNet{"1.1.1.invalidip"}},
+						},
+					},
+				},
+			},
+			wantedError: fmt.Errorf(`validate "public": parse IPNet 1.1.1.invalidip: invalid CIDR address: 1.1.1.invalidip`),
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
