@@ -18,35 +18,38 @@ const (
 
 // Available env-controller managed feature names.
 const (
-	ALBFeatureName         = "ALBWorkloads"
-	EFSFeatureName         = "EFSWorkloads"
-	NATFeatureName         = "NATWorkloads"
-	InternalALBFeatureName = "InternalALBWorkloads"
-	AliasesFeatureName     = "Aliases"
+	ALBFeatureName                     = "ALBWorkloads"
+	EFSFeatureName                     = "EFSWorkloads"
+	NATFeatureName                     = "NATWorkloads"
+	InternalALBFeatureName             = "InternalALBWorkloads"
+	AliasesFeatureName                 = "Aliases"
+	AppRunnerPrivateServiceFeatureName = "AppRunnerPrivateWorkloads"
 )
 
 // LastForceDeployIDOutputName is the logical ID of the deployment controller output.
 const LastForceDeployIDOutputName = "LastForceDeployID"
 
 var friendlyEnvFeatureName = map[string]string{
-	ALBFeatureName:         "ALB",
-	EFSFeatureName:         "EFS",
-	NATFeatureName:         "NAT Gateway",
-	InternalALBFeatureName: "Internal ALB",
-	AliasesFeatureName:     "Aliases",
+	ALBFeatureName:                     "ALB",
+	EFSFeatureName:                     "EFS",
+	NATFeatureName:                     "NAT Gateway",
+	InternalALBFeatureName:             "Internal ALB",
+	AliasesFeatureName:                 "Aliases",
+	AppRunnerPrivateServiceFeatureName: "App Runner Private Services",
 }
 
 var leastVersionForFeature = map[string]string{
-	ALBFeatureName:         "v1.0.0",
-	EFSFeatureName:         "v1.3.0",
-	NATFeatureName:         "v1.3.0",
-	InternalALBFeatureName: "v1.10.0",
-	AliasesFeatureName:     "v1.4.0",
+	ALBFeatureName:                     "v1.0.0",
+	EFSFeatureName:                     "v1.3.0",
+	NATFeatureName:                     "v1.3.0",
+	InternalALBFeatureName:             "v1.10.0",
+	AliasesFeatureName:                 "v1.4.0",
+	AppRunnerPrivateServiceFeatureName: "v1.23.0",
 }
 
 // AvailableEnvFeatures returns a list of the latest available feature, named after their corresponding parameter names.
 func AvailableEnvFeatures() []string {
-	return []string{ALBFeatureName, EFSFeatureName, NATFeatureName, InternalALBFeatureName, AliasesFeatureName}
+	return []string{ALBFeatureName, EFSFeatureName, NATFeatureName, InternalALBFeatureName, AliasesFeatureName, AppRunnerPrivateServiceFeatureName}
 }
 
 // FriendlyEnvFeatureName returns a user-friendly feature name given a env-controller managed parameter name.
@@ -78,6 +81,7 @@ var (
 		"bootstrap-resources",
 		"elb-access-logs",
 		"mappings-regional-configs",
+		"ar-vpc-connector",
 	}
 )
 
@@ -109,8 +113,8 @@ type EnvOpts struct {
 	ArtifactBucketKeyARN string
 
 	VPCConfig         VPCConfig
-	PublicHTTPConfig  HTTPConfig
-	PrivateHTTPConfig HTTPConfig
+	PublicHTTPConfig  PublicHTTPConfig
+	PrivateHTTPConfig PrivateHTTPConfig
 	Telemetry         *Telemetry
 	CDNConfig         *CDNConfig
 
@@ -121,6 +125,20 @@ type EnvOpts struct {
 	DelegateDNS bool
 }
 
+// PublicHTTPConfig represents configuration for a public facing Load Balancer.
+type PublicHTTPConfig struct {
+	HTTPConfig
+	PublicALBSourceIPs []string
+	CIDRPrefixListIDs  []string
+	ELBAccessLogs      *ELBAccessLogs
+}
+
+// PrivateHTTPConfig represents configuration for an internal Load Balancer.
+type PrivateHTTPConfig struct {
+	HTTPConfig
+	CustomALBSubnets []string
+}
+
 // HasImportedCerts returns true if any https certificates have been
 // imported to the environment.
 func (e *EnvOpts) HasImportedCerts() bool {
@@ -131,10 +149,8 @@ func (e *EnvOpts) HasImportedCerts() bool {
 
 // HTTPConfig represents configuration for a Load Balancer.
 type HTTPConfig struct {
-	CIDRPrefixListIDs []string
-	ImportedCertARNs  []string
-	CustomALBSubnets  []string
-	ELBAccessLogs     *ELBAccessLogs
+	SSLPolicy        *string
+	ImportedCertARNs []string
 }
 
 // ELBAccessLogs represents configuration for ELB access logs S3 bucket.
@@ -162,6 +178,7 @@ type VPCConfig struct {
 	Managed             ManagedVPC
 	AllowVPCIngress     bool
 	SecurityGroupConfig *SecurityGroupConfig
+	FlowLogs            *VPCFlowLogs
 }
 
 // ImportVPC holds the fields to import VPC resources.
@@ -198,6 +215,11 @@ type SecurityGroupRule struct {
 	ToPort     int
 }
 
+// VPCFlowLogs holds the fields to configure logging IP traffic using VPC flow logs.
+type VPCFlowLogs struct {
+	Retention *int
+}
+
 // ParseEnv parses an environment's CloudFormation template with the specified data object and returns its content.
 func (t *Template) ParseEnv(data *EnvOpts) (*Content, error) {
 	tpl, err := t.parse("base", envCFTemplatePath, withEnvParsingFuncs())
@@ -250,6 +272,14 @@ func withEnvParsingFuncs() ParseOption {
 			"inc":      IncFunc,
 			"fmtSlice": FmtSliceFunc,
 			"quote":    strconv.Quote,
+			"truncate": truncate,
 		})
 	}
 }
+
+func truncate(s string, maxLen int) string {
+	if len(s) < maxLen {
+		return s
+	}
+	return s[:maxLen]
+}
