@@ -67,6 +67,11 @@ const (
 	LogicalIDHTTPListenerRuleWithDomain = "HTTPListenerRuleWithDomain"
 )
 
+const (
+	// NoExposedContainerPort indicates no port should be exposed for the service container.
+	NoExposedContainerPort = "-1"
+)
+
 var (
 	// Template names under "workloads/partials/cf/".
 	partialsWorkloadCFTemplateNames = []string{
@@ -121,7 +126,7 @@ type WorkloadNestedStackOpts struct {
 
 // SidecarOpts holds configuration that's needed if the service has sidecar containers.
 type SidecarOpts struct {
-	Name         *string
+	Name         string
 	Image        *string
 	Essential    *bool
 	Port         *string
@@ -145,6 +150,7 @@ type SidecarStorageOpts struct {
 // StorageOpts holds data structures for rendering Volumes and Mount Points
 type StorageOpts struct {
 	Ephemeral         *int
+	ReadonlyRootFS    *bool
 	Volumes           []*Volume
 	MountPoints       []*MountPoint
 	EFSPerms          []*EFSPermission
@@ -210,8 +216,13 @@ type LogConfigOpts struct {
 
 // HTTPTargetContainer represents the target group of a load balancer that points to a container.
 type HTTPTargetContainer struct {
-	Container string
-	Port      string // Port of the container.
+	Name string
+	Port string
+}
+
+// Exposed returns true if the target container has an accessible port to receive traffic.
+func (tg HTTPTargetContainer) Exposed() bool {
+	return tg.Port != "" && tg.Port != NoExposedContainerPort
 }
 
 // IsHTTPS returns true if the target container's port is 443.
@@ -331,8 +342,7 @@ type NetworkLoadBalancer struct {
 
 // ServiceConnect holds configuration for ECS Service Connect.
 type ServiceConnect struct {
-	Namespace string
-	Alias     *string
+	Alias *string
 }
 
 // AdvancedCount holds configuration for autoscaling and capacity provider
@@ -585,9 +595,12 @@ type WorkloadOpts struct {
 	StateMachine       *StateMachineOpts
 
 	// Additional options for request driven web service templates.
-	StartCommand      *string
-	EnableHealthCheck bool
-	Observability     ObservabilityOpts
+	StartCommand         *string
+	EnableHealthCheck    bool
+	Observability        ObservabilityOpts
+	Private              bool
+	AppRunnerVPCEndpoint *string
+	Count                *string
 
 	// Input needed for the custom resource that adds a custom domain to the service.
 	Alias                *string
@@ -730,6 +743,11 @@ func envControllerParameters(o WorkloadOpts) []string {
 			parameters = append(parameters, "InternalALBWorkloads,")
 		}
 	}
+	if o.WorkloadType == "Request-Driven Web Service" {
+		if o.Private && o.AppRunnerVPCEndpoint == nil {
+			parameters = append(parameters, "AppRunnerPrivateWorkloads,")
+		}
+	}
 	if o.Network.SubnetsType == PrivateSubnetsPlacement {
 		parameters = append(parameters, "NATWorkloads,")
 	}
