@@ -8,8 +8,6 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/dustin/go-humanize"
-
 	"github.com/aws/aws-sdk-go/aws"
 	awsecs "github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/config"
@@ -19,6 +17,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
 	"github.com/aws/copilot-cli/internal/pkg/term/selector/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
+	"github.com/dustin/go-humanize"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 )
@@ -2392,266 +2391,6 @@ func TestSelect_Application(t *testing.T) {
 	}
 }
 
-func TestOther_Dockerfile(t *testing.T) {
-	dockerfiles := []string{
-		"./Dockerfile",
-		"backend/Dockerfile",
-		"frontend/Dockerfile",
-	}
-	dockerfileOptions := []string{
-		"./Dockerfile",
-		"backend/Dockerfile",
-		"frontend/Dockerfile",
-		"Enter custom path for your Dockerfile",
-		"Use an existing image instead",
-	}
-	testCases := map[string]struct {
-		mockWs     func(retriever *mocks.MockworkspaceRetriever)
-		mockPrompt func(*mocks.Mockprompter)
-
-		wantedErr        error
-		wantedDockerfile string
-	}{
-		"choose an existing Dockerfile": {
-			mockWs: func(m *mocks.MockworkspaceRetriever) {
-				m.EXPECT().ListDockerfiles().Return(dockerfiles, nil)
-			},
-			mockPrompt: func(m *mocks.Mockprompter) {
-				m.EXPECT().SelectOne(
-					gomock.Any(), gomock.Any(),
-					gomock.Eq(dockerfileOptions),
-					gomock.Any(),
-				).Return("frontend/Dockerfile", nil)
-			},
-			wantedErr:        nil,
-			wantedDockerfile: "frontend/Dockerfile",
-		},
-		"prompts user for custom path": {
-			mockWs: func(m *mocks.MockworkspaceRetriever) {
-				m.EXPECT().ListDockerfiles().Return([]string{}, nil)
-			},
-			mockPrompt: func(m *mocks.Mockprompter) {
-				m.EXPECT().SelectOne(
-					gomock.Any(), gomock.Any(),
-					gomock.Eq([]string{
-						"Enter custom path for your Dockerfile",
-						"Use an existing image instead",
-					}),
-					gomock.Any(),
-				).Return("Enter custom path for your Dockerfile", nil)
-				m.EXPECT().Get(
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-				).Return("crazy/path/Dockerfile", nil)
-			},
-			wantedErr:        nil,
-			wantedDockerfile: "crazy/path/Dockerfile",
-		},
-		"returns an error if fail to list Dockerfile": {
-			mockWs: func(m *mocks.MockworkspaceRetriever) {
-				m.EXPECT().ListDockerfiles().Return(nil, errors.New("some error"))
-			},
-			mockPrompt: func(m *mocks.Mockprompter) {},
-			wantedErr:  fmt.Errorf("list Dockerfiles: some error"),
-		},
-		"returns an error if fail to select Dockerfile": {
-			mockWs: func(m *mocks.MockworkspaceRetriever) {
-				m.EXPECT().ListDockerfiles().Return(dockerfiles, nil)
-			},
-			mockPrompt: func(m *mocks.Mockprompter) {
-				m.EXPECT().SelectOne(
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-				).Return("", errors.New("some error"))
-			},
-			wantedErr: fmt.Errorf("select Dockerfile: some error"),
-		},
-		"returns an error if fail to get custom Dockerfile path": {
-			mockWs: func(m *mocks.MockworkspaceRetriever) {
-				m.EXPECT().ListDockerfiles().Return(dockerfiles, nil)
-			},
-			mockPrompt: func(m *mocks.Mockprompter) {
-				m.EXPECT().SelectOne(
-					gomock.Any(), gomock.Any(),
-					gomock.Eq(dockerfileOptions),
-					gomock.Any(),
-				).Return("Enter custom path for your Dockerfile", nil)
-				m.EXPECT().Get(
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-					gomock.Any(),
-				).Return("", errors.New("some error"))
-			},
-			wantedErr: fmt.Errorf("get custom Dockerfile path: some error"),
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			ctrl := gomock.NewController(t)
-			defer ctrl.Finish()
-			p := mocks.NewMockprompter(ctrl)
-			cfg := mocks.NewMockworkspaceRetriever(ctrl)
-			tc.mockPrompt(p)
-			tc.mockWs(cfg)
-
-			sel := WorkspaceSelector{
-				prompt: p,
-				ws:     cfg,
-			}
-
-			mockPromptText := "prompt"
-			mockHelpText := "help"
-
-			// WHEN
-			dockerfile, err := sel.Dockerfile(
-				mockPromptText,
-				mockPromptText,
-				mockHelpText,
-				mockHelpText,
-				func(v interface{}) error { return nil },
-			)
-
-			// THEN
-			if tc.wantedErr != nil {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			} else {
-				require.Equal(t, tc.wantedDockerfile, dockerfile)
-			}
-		})
-	}
-}
-
-func TestWorkspaceSelect_Schedule(t *testing.T) {
-	scheduleTypePrompt := "HAY WHAT SCHEDULE"
-	scheduleTypeHelp := "NO"
-
-	testCases := map[string]struct {
-		mockWs         func(retriever *mocks.MockworkspaceRetriever)
-		mockPrompt     func(*mocks.Mockprompter)
-		wantedSchedule string
-		wantedErr      error
-	}{
-		"error asking schedule type": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return("", errors.New("some error")),
-				)
-			},
-			wantedErr: errors.New("get schedule type: some error"),
-		},
-		"ask for rate": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(rate, nil),
-					m.EXPECT().Get(ratePrompt, rateHelp, gomock.Any(), gomock.Any()).Return("1h30m", nil),
-				)
-			},
-			wantedSchedule: "@every 1h30m",
-		},
-		"error getting rate": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(rate, nil),
-					m.EXPECT().Get(ratePrompt, rateHelp, gomock.Any(), gomock.Any()).Return("", fmt.Errorf("some error")),
-				)
-			},
-			wantedErr: errors.New("get schedule rate: some error"),
-		},
-		"ask for cron": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Daily", nil),
-				)
-			},
-			wantedSchedule: "@daily",
-		},
-		"error getting cron": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("", errors.New("some error")),
-				)
-			},
-			wantedErr: errors.New("get preset schedule: some error"),
-		},
-		"ask for custom schedule": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
-					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("0 * * * *", nil),
-					m.EXPECT().Confirm(humanReadableCronConfirmPrompt, humanReadableCronConfirmHelp).Return(true, nil),
-				)
-			},
-			wantedSchedule: "0 * * * *",
-		},
-		"error getting custom schedule": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
-					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("", errors.New("some error")),
-				)
-			},
-			wantedErr: errors.New("get custom schedule: some error"),
-		},
-		"error confirming custom schedule": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
-					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("0 * * * *", nil),
-					m.EXPECT().Confirm(humanReadableCronConfirmPrompt, humanReadableCronConfirmHelp).Return(false, errors.New("some error")),
-				)
-			},
-			wantedErr: errors.New("confirm cron schedule: some error"),
-		},
-		"custom schedule using valid definition string results in no confirm": {
-			mockPrompt: func(m *mocks.Mockprompter) {
-				gomock.InOrder(
-					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
-					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("@hourly", nil),
-				)
-			},
-			wantedSchedule: "@hourly",
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			ctrl := gomock.NewController(t)
-			defer ctrl.Finish()
-			p := mocks.NewMockprompter(ctrl)
-			cfg := mocks.NewMockworkspaceRetriever(ctrl)
-			tc.mockPrompt(p)
-			sel := WorkspaceSelector{
-				prompt: p,
-				ws:     cfg,
-			}
-
-			var mockValidator prompt.ValidatorFunc = func(interface{}) error { return nil }
-
-			// WHEN
-			schedule, err := sel.Schedule(scheduleTypePrompt, scheduleTypeHelp, mockValidator, mockValidator)
-
-			// THEN
-			if tc.wantedErr != nil {
-				require.EqualError(t, err, tc.wantedErr.Error())
-			} else {
-				require.Equal(t, tc.wantedSchedule, schedule)
-			}
-		})
-	}
-}
-
 type wsPipelineSelectMocks struct {
 	prompt *mocks.Mockprompter
 	ws     *mocks.MockwsPipelinesLister
