@@ -31,11 +31,9 @@ func TestWorkspace_Path(t *testing.T) {
 	const workspaceDir = "test"
 
 	testCases := map[string]struct {
-		expectedPath      string
-		presetManifestDir string
-		workingDir        string
-		expectedError     error
-		mockFileSystem    func(fs afero.Fs)
+		expectedPath   string
+		workingDir     string
+		mockFileSystem func(fs afero.Fs)
 	}{
 		"same directory level": {
 			expectedPath: workspaceDir,
@@ -44,7 +42,6 @@ func TestWorkspace_Path(t *testing.T) {
 				fs.MkdirAll("test/copilot", 0755)
 			},
 		},
-
 		"same directory": {
 			expectedPath: workspaceDir,
 			workingDir:   filepath.FromSlash("test/copilot"),
@@ -52,7 +49,6 @@ func TestWorkspace_Path(t *testing.T) {
 				fs.MkdirAll("test/copilot", 0755)
 			},
 		},
-
 		"several levels deep": {
 			expectedPath: workspaceDir,
 			workingDir:   filepath.FromSlash("test/1/2/3/4"),
@@ -61,29 +57,10 @@ func TestWorkspace_Path(t *testing.T) {
 				fs.MkdirAll("test/1/2/3/4", 0755)
 			},
 		},
-
-		"too many levels deep": {
-			expectedError: fmt.Errorf("couldn't find a directory called copilot up to 5 levels up from %s", filepath.FromSlash("test/1/2/3/4/5")),
-			workingDir:    filepath.FromSlash("test/1/2/3/4/5"),
-			mockFileSystem: func(fs afero.Fs) {
-				fs.MkdirAll("test/copilot", 0755)
-				fs.MkdirAll("test/1/2/3/4/5", 0755)
-			},
-		},
-
-		"out of a workspace": {
-			expectedError: fmt.Errorf("couldn't find a directory called copilot up to 5 levels up from %s", filepath.FromSlash("/")),
-			workingDir:    filepath.FromSlash("/"),
-			mockFileSystem: func(fs afero.Fs) {
-				fs.MkdirAll("test/copilot", 0755)
-			},
-		},
-
 		"uses precomputed manifest path": {
-			expectedPath:      workspaceDir,
-			workingDir:        filepath.FromSlash("/"),
-			mockFileSystem:    func(fs afero.Fs) {},
-			presetManifestDir: filepath.FromSlash("test/copilot"),
+			expectedPath:   workspaceDir,
+			workingDir:     filepath.FromSlash("/"),
+			mockFileSystem: func(fs afero.Fs) {},
 		},
 	}
 	for name, tc := range testCases {
@@ -96,48 +73,50 @@ func TestWorkspace_Path(t *testing.T) {
 			ws := Workspace{
 				workingDirAbs: tc.workingDir,
 				fs:            &afero.Afero{Fs: fs},
-				copilotDirAbs: tc.presetManifestDir,
-			}
-			workspacePath, err := ws.Path()
-			if tc.expectedError == nil {
-				require.NoError(t, err)
-				require.Equal(t, tc.expectedPath, workspacePath)
-			} else {
-				require.Equal(t, tc.expectedError.Error(), err.Error())
+				copilotDirAbs: filepath.FromSlash("test/copilot"),
 			}
+			workspacePath := ws.Path()
+			require.Equal(t, tc.expectedPath, workspacePath)
 		})
 	}
 }
 
 func TestWorkspace_Summary(t *testing.T) {
 	testCases := map[string]struct {
+		workingDir     string
+		mockFileSystem func(fs afero.Fs)
+
 		expectedSummary Summary
-		workingDir      string
 		expectedError   error
-		mockFileSystem  func(fs afero.Fs)
 	}{
 		"existing workspace summary": {
-			expectedSummary: Summary{
-				Application: "DavidsApp",
-				Path:        filepath.FromSlash("test/copilot/.workspace"),
-			},
 			workingDir: "test/",
 			mockFileSystem: func(fs afero.Fs) {
 				fs.MkdirAll("test/copilot", 0755)
 				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
 			},
+			expectedSummary: Summary{
+				Application: "DavidsApp",
+				Path:        filepath.FromSlash("test/copilot/.workspace"),
+			},
+		},
+		"existing workspace summary in a parent dir": {
+			workingDir: "test/app",
+			mockFileSystem: func(fs afero.Fs) {
+				fs.MkdirAll("test/copilot", 0755)
+				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+			},
+			expectedSummary: Summary{
+				Application: "DavidsApp",
+				Path:        filepath.FromSlash("test/copilot/.workspace"),
+			},
 		},
 		"no existing workspace summary": {
-			workingDir:    "test/",
-			expectedError: fmt.Errorf("couldn't find an application associated with this workspace"),
+			workingDir: "test/",
 			mockFileSystem: func(fs afero.Fs) {
 				fs.MkdirAll("test/copilot", 0755)
 			},
-		},
-		"no existing manifest dir": {
-			workingDir:     "test/",
-			expectedError:  fmt.Errorf("couldn't find a directory called copilot up to 5 levels up from test/"),
-			mockFileSystem: func(fs afero.Fs) {},
+			expectedError: &ErrNoAssociatedApplication{},
 		},
 	}
 	for name, tc := range testCases {
@@ -148,6 +127,7 @@ func TestWorkspace_Summary(t *testing.T) {
 			tc.mockFileSystem(fs)
 
 			ws := Workspace{
+				copilotDirAbs: filepath.Join("test", CopilotDirName),
 				workingDirAbs: tc.workingDir,
 				fs:            &afero.Afero{Fs: fs},
 			}
@@ -163,79 +143,170 @@ func TestWorkspace_Summary(t *testing.T) {
 }
 
 func TestWorkspace_Create(t *testing.T) {
+	wd, err := os.Getwd()
+	require.NoError(t, err)
+	parent := filepath.Dir(wd)
 	testCases := map[string]struct {
 		appName        string
-		workingDir     string
-		expectedError  error
-		expectNoWrites bool
-		mockFileSystem func(fs afero.Fs)
+		mockFileSystem func() afero.Fs
+
+		expectedError         error
+		expectedCopilotDirAbs string
 	}{
-		"existing workspace and workspace summary": {
-			workingDir:     "test/",
-			appName:        "DavidsApp",
-			expectNoWrites: true,
-			mockFileSystem: func(fs afero.Fs) {
-				fs.MkdirAll("test/copilot", 0755)
-				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+		"successful no-op with existing workspace and summary": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+				_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", wd), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+				fs = afero.NewReadOnlyFs(fs) // No write/
+				return fs
 			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", wd),
 		},
-		"existing workspace and workspace summary in different directory": {
-			workingDir:     "test/app/",
-			appName:        "DavidsApp",
-			expectNoWrites: true,
-			mockFileSystem: func(fs afero.Fs) {
-				fs.MkdirAll("test/copilot", 0755)
-				fs.MkdirAll("test/app", 0755)
-				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+		"successful no-op with existing workspace and summary in a parent directory": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", parent), 0755)
+				_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", parent), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+				fs = afero.NewReadOnlyFs(fs) // No write.
+				return fs
 			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", parent),
 		},
-		"existing workspace and different application": {
-			workingDir:    "test/",
-			appName:       "DavidsApp",
+		"error if workspace exists but associated with different application": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+				_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", wd), []byte(fmt.Sprintf("---\napplication: %s", "DavidsOtherApp")), 0644)
+				fs = afero.NewReadOnlyFs(fs) // No write.
+				return fs
+			},
 			expectedError: fmt.Errorf("workspace is already registered with application DavidsOtherApp under %s", filepath.FromSlash("copilot/.workspace")),
-			mockFileSystem: func(fs afero.Fs) {
-				fs.MkdirAll("test/copilot", 0755)
-				afero.WriteFile(fs, "test/copilot/.workspace", []byte(fmt.Sprintf("---\napplication: %s", "DavidsOtherApp")), 0644)
-			},
 		},
-		"existing workspace but no workspace summary": {
-			workingDir: "test/",
-			appName:    "DavidsApp",
-			mockFileSystem: func(appFS afero.Fs) {
-				appFS.MkdirAll("test/copilot", 0755)
+		"successfully create a work summary if workspace existing but no workspace summary": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+				return fs
 			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", wd),
 		},
-		"no existing workspace or workspace summary": {
-			workingDir:     "test/",
-			appName:        "DavidsApp",
-			mockFileSystem: func(fs afero.Fs) {},
+		"successfully create both workspace and summary if neither exists": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				return afero.NewMemMapFs()
+			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", wd),
 		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			// Create an empty FileSystem
-			fs := afero.NewMemMapFs()
-			// Set it up
-			tc.mockFileSystem(fs)
-			// Throw an error if someone tries to write
-			// if we expect there to be no writes.
-			if tc.expectNoWrites {
-				fs = afero.NewReadOnlyFs(fs)
-			}
-
-			ws := Workspace{
-				workingDirAbs: tc.workingDir,
-				fs:            &afero.Afero{Fs: fs},
-			}
-			err := ws.Create(tc.appName)
+			// Set up filesystem.
+			gotWS, err := Create(tc.appName, tc.mockFileSystem())
 			if tc.expectedError == nil {
 				// an operation not permitted error means
 				// we tried to write to the filesystem, but
 				// the test indicated that we expected no writes.
 				require.NoError(t, err)
-				summary, err := ws.Summary()
+
+				// Validate that the stored copilot dir path is correct.
+				require.Equal(t, tc.expectedCopilotDirAbs, gotWS.copilotDirAbs)
+
+				// Validate that the workspace dir is created.
+				exist, err := gotWS.fs.Exists(tc.expectedCopilotDirAbs)
 				require.NoError(t, err)
-				require.Equal(t, tc.appName, summary.Application)
+				require.True(t, exist)
+
+				// Validate that the summary file is associated with the app.
+				gotSummary, err := gotWS.Summary()
+				require.NoError(t, err)
+				require.Equal(t, tc.appName, gotSummary.Application)
+
+			} else {
+				require.Equal(t, tc.expectedError.Error(), err.Error())
+			}
+		})
+	}
+}
+
+func TestWorkspace_Use(t *testing.T) {
+	wd, err := os.Getwd()
+	require.NoError(t, err)
+	parent := filepath.Dir(wd)
+	testCases := map[string]struct {
+		appName        string
+		mockFileSystem func() afero.Fs
+
+		expectedError         error
+		expectedCopilotDirAbs string
+	}{
+		"returns the existing workspace that has the summary": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+				_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", wd), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+				fs = afero.NewReadOnlyFs(fs) // No write/
+				return fs
+			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", wd),
+		},
+		"returns the existing workspace and workspace summary in a parent directory": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", parent), 0755)
+				_ = afero.WriteFile(fs, fmt.Sprintf("%s/copilot/.workspace", parent), []byte(fmt.Sprintf("---\napplication: %s", "DavidsApp")), 0644)
+				fs = afero.NewReadOnlyFs(fs) // No write.
+				return fs
+			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", parent),
+		},
+		"returns an ErrNoAssociatedApplication error when there is existing copilot/ directory that does not have a workspace summary": {
+			appName: "DavidsApp",
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/copilot", wd), 0755)
+				return fs
+			},
+			expectedCopilotDirAbs: fmt.Sprintf("%s/copilot", wd),
+			expectedError:         &ErrNoAssociatedApplication{},
+		},
+		"ErrWorkspaceNotFound if there is no workspace": {
+			mockFileSystem: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				_ = fs.MkdirAll(fmt.Sprintf("%s/webhook", wd), 0755)
+				return fs
+			},
+			expectedError: &ErrWorkspaceNotFound{
+				CurrentDirectory:      wd,
+				ManifestDirectoryName: CopilotDirName,
+				NumberOfLevelsChecked: maximumParentDirsToSearch,
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// Set up filesystem.
+			gotWS, err := Use(tc.mockFileSystem())
+			if tc.expectedError == nil {
+				// an operation not permitted error means
+				// we tried to write to the filesystem, but
+				// the test indicated that we expected no writes.
+				require.NoError(t, err)
+
+				// Validate that the stored copilot dir path is correct.
+				require.Equal(t, tc.expectedCopilotDirAbs, gotWS.copilotDirAbs)
+
+				// Validate that the workspace dir is there.
+				exist, err := gotWS.fs.Exists(tc.expectedCopilotDirAbs)
+				require.NoError(t, err)
+				require.True(t, exist)
+
 			} else {
 				require.Equal(t, tc.expectedError.Error(), err.Error())
 			}
@@ -754,18 +825,6 @@ version: 1
 			wantedLog: fmt.Sprintf("Unable to read pipeline manifest at '%s': unmarshal pipeline manifest: yaml: unmarshal errors:\n  line 3: cannot unmarshal !!str `invalid...` into manifest.PipelineSchemaMajorVersion\n",
 				filepath.FromSlash("/copilot/pipelines/beta/manifest.yml")),
 		},
-		"handles missing copilot directory error": {
-			copilotDir: "",
-			fs: func() afero.Fs {
-				fs := afero.NewMemMapFs()
-				return fs
-			},
-			wantedPipelines: nil,
-			wantedErr: &ErrWorkspaceNotFound{
-				ManifestDirectoryName: CopilotDirName,
-				NumberOfLevelsChecked: maximumParentDirsToSearch,
-			},
-		},
 	}
 
 	for name, tc := range testCases {
@@ -828,21 +887,151 @@ func TestIsInGitRepository(t *testing.T) {
 	}
 }
 
-func TestWorkspace_ReadAddonsDir(t *testing.T) {
+func TestWorkspace_EnvAddonsPath(t *testing.T) {
+	mockWorkingDirAbs := "/app"
 	testCases := map[string]struct {
-		svcName        string
-		copilotDirPath string
-		fs             func() afero.Fs
+		fs         func() afero.Fs
+		wantedPath string
+	}{
+		"returns the correct env addons path": {
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/addons/", 0755)
+				return fs
+			},
+			wantedPath: "/copilot/environments/addons",
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDirAbs: "/copilot/",
+				workingDirAbs: mockWorkingDirAbs,
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			got := ws.EnvAddonsPath()
+			require.Equal(t, tc.wantedPath, got)
+		})
+	}
+}
+
+func TestWorkspace_EnvAddonFilePath(t *testing.T) {
+	mockWorkingDirAbs := "/app"
+	testCases := map[string]struct {
+		fName      string
+		fs         func() afero.Fs
+		wantedPath string
+		wantedErr  error
+	}{
+		"returns the correct env addon file path": {
+			fName: "db.yml",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/addons/db.yml", 0755)
+				return fs
+			},
+			wantedPath: "/copilot/environments/addons/db.yml",
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDirAbs: "/copilot",
+				workingDirAbs: mockWorkingDirAbs,
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			got := ws.EnvAddonFilePath(tc.fName)
+			require.Equal(t, tc.wantedPath, got)
+		})
+	}
+}
+
+func TestWorkspace_WorkloadAddonsPath(t *testing.T) {
+	mockWorkingDirAbs := "/app"
+	testCases := map[string]struct {
+		fs         func() afero.Fs
+		wantedPath string
+	}{
+		"returns the correct workload addons path": {
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/mockSvc/addons/", 0755)
+				return fs
+			},
+			wantedPath: "/copilot/mockSvc/addons",
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDirAbs: "/copilot/",
+				workingDirAbs: mockWorkingDirAbs,
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			got := ws.WorkloadAddonsPath("mockSvc")
+			require.Equal(t, tc.wantedPath, got)
+		})
+	}
+}
+
+func TestWorkspace_WorkloadAddonFilePath(t *testing.T) {
+	mockWorkingDirAbs := "/app"
+	testCases := map[string]struct {
+		svc        string
+		fName      string
+		fs         func() afero.Fs
+		wantedPath string
+		wantedErr  error
+	}{
+		"returns the correct env addon file path": {
+			svc:   "webhook",
+			fName: "db.yml",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/webhook/addons/db.yml", 0755)
+				return fs
+			},
+			wantedPath: "/copilot/webhook/addons/db.yml",
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDirAbs: "/copilot/",
+				workingDirAbs: mockWorkingDirAbs,
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			got := ws.WorkloadAddonFilePath(tc.svc, tc.fName)
+			require.Equal(t, tc.wantedPath, got)
+		})
+	}
+}
+
+func TestWorkspace_ListFiles(t *testing.T) {
+	testCases := map[string]struct {
+		inDirPath string
+		fs        func() afero.Fs
 
 		wantedFileNames []string
 		wantedErr       error
 	}{
 		"dir not exist": {
-			svcName:        "webhook",
-			copilotDirPath: "/copilot",
+			inDirPath: "/copilot/webhook/addons",
 			fs: func() afero.Fs {
 				fs := afero.NewMemMapFs()
-				fs.MkdirAll("/copilot/webhook", 0755)
+				fs.MkdirAll("/copilot/webhook/", 0755)
 				return fs
 			},
 			wantedErr: &os.PathError{
@@ -852,8 +1041,7 @@ func TestWorkspace_ReadAddonsDir(t *testing.T) {
 			},
 		},
 		"retrieves file names": {
-			svcName:        "webhook",
-			copilotDirPath: "/copilot",
+			inDirPath: "/copilot/webhook/addons",
 			fs: func() afero.Fs {
 				fs := afero.NewMemMapFs()
 				fs.MkdirAll("/copilot/webhook/addons", 0755)
@@ -871,14 +1059,14 @@ func TestWorkspace_ReadAddonsDir(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			// GIVEN
 			ws := &Workspace{
-				copilotDirAbs: tc.copilotDirPath,
+				copilotDirAbs: "copilot/",
 				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
 
 			// WHEN
-			actualFileNames, actualErr := ws.ReadAddonsDir(tc.svcName)
+			actualFileNames, actualErr := ws.ListFiles(tc.inDirPath)
 
 			// THEN
 			require.Equal(t, tc.wantedErr, actualErr)
@@ -887,6 +1075,56 @@ func TestWorkspace_ReadAddonsDir(t *testing.T) {
 	}
 }
 
+func TestWorkspace_ReadFile(t *testing.T) {
+	testCases := map[string]struct {
+		fPath string
+		fs    func() afero.Fs
+
+		wantedData []byte
+		wantedErr  error
+	}{
+		"return error if file does not exist": {
+			fPath: "/copilot/api/addons/db.yml",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				return fs
+			},
+			wantedErr: fmt.Errorf("file %s does not exists", filepath.FromSlash("/copilot/api/addons/db.yml")),
+		},
+		"read existing file": {
+			fPath: "/copilot/environments/addons/db.yml",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/addons", 0755)
+				f, _ := fs.Create("/copilot/environments/addons/db.yml")
+				defer f.Close()
+				f.Write([]byte("mydb"))
+				return fs
+			},
+
+			wantedData: []byte("mydb"),
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDirAbs: "/copilot",
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+			data, err := ws.ReadFile(tc.fPath)
+			if tc.wantedErr == nil {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedData, data)
+			} else {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			}
+		})
+	}
+}
+
 func TestWorkspace_WriteAddon(t *testing.T) {
 	testCases := map[string]struct {
 		marshaler   mockBinaryMarshaler
@@ -1237,81 +1475,6 @@ func TestWorkspace_DeleteWorkspaceFile(t *testing.T) {
 	}
 }
 
-func TestWorkspace_ListDockerfiles(t *testing.T) {
-	wantedDockerfiles := []string{"./Dockerfile", "backend/Dockerfile", "frontend/Dockerfile"}
-	testCases := map[string]struct {
-		mockFileSystem func(mockFS afero.Fs)
-		err            error
-		dockerfiles    []string
-	}{
-		"find Dockerfiles": {
-			mockFileSystem: func(mockFS afero.Fs) {
-				mockFS.MkdirAll("frontend", 0755)
-				mockFS.MkdirAll("backend", 0755)
-
-				afero.WriteFile(mockFS, "Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "frontend/Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "backend/Dockerfile", []byte("FROM nginx"), 0644)
-			},
-			err:         nil,
-			dockerfiles: wantedDockerfiles,
-		},
-		"exclude dockerignore files": {
-			mockFileSystem: func(mockFS afero.Fs) {
-				mockFS.MkdirAll("frontend", 0755)
-				mockFS.MkdirAll("backend", 0755)
-
-				afero.WriteFile(mockFS, "Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "frontend/Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "frontend/Dockerfile.dockerignore", []byte("*/temp*"), 0644)
-				afero.WriteFile(mockFS, "backend/Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "backend/Dockerfile.dockerignore", []byte("*/temp*"), 0644)
-			},
-			err:         nil,
-			dockerfiles: wantedDockerfiles,
-		},
-		"nonstandard Dockerfile names": {
-			mockFileSystem: func(mockFS afero.Fs) {
-				mockFS.MkdirAll("frontend", 0755)
-				mockFS.MkdirAll("dockerfiles", 0755)
-				afero.WriteFile(mockFS, "Dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "frontend/dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "Job.dockerfile", []byte("FROM nginx"), 0644)
-				afero.WriteFile(mockFS, "Job.dockerfile.dockerignore", []byte("*/temp*"), 0644)
-			},
-			err:         nil,
-			dockerfiles: []string{"./Dockerfile", "./Job.dockerfile", "frontend/dockerfile"},
-		},
-		"no Dockerfiles": {
-			mockFileSystem: func(mockFS afero.Fs) {},
-			dockerfiles:    []string{},
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			fs := &afero.Afero{Fs: afero.NewMemMapFs()}
-			tc.mockFileSystem(fs)
-			ws := &Workspace{
-				workingDirAbs: "/",
-				copilotDirAbs: "copilot",
-				fs: &afero.Afero{
-					Fs: fs,
-				},
-			}
-			got, err := ws.ListDockerfiles()
-
-			if tc.err != nil {
-				require.EqualError(t, err, tc.err.Error())
-			} else {
-				require.NoError(t, err)
-				require.Equal(t, tc.dockerfiles, got)
-			}
-		})
-	}
-}
-
 func TestWorkspace_read(t *testing.T) {
 	testCases := map[string]struct {
 		elems []string
